/*
 *      sigtest.c
 *
 *      Copyright 2007 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "geany.h"
#include "Scintilla.h"
#include "support.h"
#include "plugindata.h"
#include "geanyobject.h"	// only needed for GCB_ enum
#include "document.h"


PluginFields	*plugin_fields;
GeanyData		*geany_data;


#define doc_array       geany_data->doc_array

VERSION_CHECK(9)

/* All plugins must set name and description */
PLUGIN_INFO(_("SigTest"), _("Test plugin."))


static void on_doc(GObject *obj, gint idx, gpointer user_data)
{
	gint id = GPOINTER_TO_INT(user_data);

	switch(id)
	{
		case GCB_DOCUMENT_NEW:	printf("New"); break;
		case GCB_DOCUMENT_OPEN:	printf("Open"); break;
		case GCB_DOCUMENT_SAVE:	printf("Save"); break;
	}
	printf(" - %s, %d\n", DOC_FILENAME(idx), FILETYPE_ID(doc_list[idx].file_type));
}

GeanyCallback	geany_callbacks[] = {
	{"document-new", (GCallback) &on_doc, FALSE, GINT_TO_POINTER(GCB_DOCUMENT_NEW)},
	{"document-open", (GCallback) &on_doc, FALSE, GINT_TO_POINTER(GCB_DOCUMENT_OPEN)},
	{"document-save", (GCallback) &on_doc, FALSE, GINT_TO_POINTER(GCB_DOCUMENT_SAVE)},
	{NULL, NULL, FALSE, NULL}
	};


void init(GeanyData *data)
{
	GtkWidget *demo_item;

	// Add an item to the Tools menu
	demo_item = gtk_menu_item_new_with_mnemonic(info()->name);
	gtk_widget_show(demo_item);
	gtk_container_add(GTK_CONTAINER(geany_data->tools_menu), demo_item);

	// keep a pointer to the menu item, so we can remove it when the plugin is unloaded
	plugin_fields->menu_item = demo_item;
}


void cleanup()
{
	// remove the menu item added in init()
	gtk_widget_destroy(plugin_fields->menu_item);
}

